//
//  led7seg.h
//
//  7-Sengent LED Control
//  Copyright (C) 2009-2011 Toyohiko Togashi tog001@nifty.com
//
//  This program is free software; you can redistribute it and/or modify it under the terms of the
//  GNU General Public License as published by the Free Software Foundation; either version 3
//  of the License, or (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
//  without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
//  See the GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License along with this program.
//  If not, see <http://www.gnu.org/licenses/>
//
//
//	Description
//		7-Segment LEDs display control subroutine.
//		Supported 2~8digits anode/cathode common type.
//		Any signal porality.
//		Digit signal is continous port bits. ex.dig1=b0 dig2=b1 dig3=b2...
//		Segment signal connection is fixed. a=b0= b=b1 c=b3 ... g=b6 dot=b7
//
//  Device: PIC16F88         IDE: MPLAB IDE 8.36, HI-TECH C Tools for the PIC10/12/16 MCU Family Version 9.60PL5
//  Device: PIC18F14K50      IDE: MPLAB IDE 8.36, C Compiler for PIC18 MCUs v3.33
//
//
//    Update history
//    ---------- ----- -------------------------------------------
//    2009.04.23 v0.0  1st rel(BDCM version,PIC16F88 only)
//    2011.01.01 v0.1  Support PIC18/C18
//


#ifndef LED7SEG_H
#define LED7SEG_H

//
//	Configure
//
//#include "htc.h" // PIC16F88/HI-TECH C
//#define LED7SEG_DIG_PORT	PORTA		// Output register "87654321"
//#define LED7SEG_DIG_TRIS	TRISA		// Direction register
//#define LED7SEG_DIG_POL	1			// Active low=0 high=1
//#define LED7SEG_DIG_SBIT	2			// Start bit(0~7)
//#define LED7SEG_DIG_WIDTH	3			// Physical column(2~8)
//#define LED7SEG_DIG_REV				// Right->Left
//#define LED7SEG_SEG_PORT	PORTB		// Output register ".gfedcba"
//#define LED7SEG_SEG_TRIS	TRISB		// Direction register
//#define LED7SEG_SEG_POL	0			// Active low=0 high=1
#include "p18f14K50.h"
#define LED7SEG_DIG_PORT	LATB		// Output register "87654321"
#define LED7SEG_DIG_TRIS	TRISB		// Direction register
#define LED7SEG_DIG_POL		1			// Active low=0 high=1
#define LED7SEG_DIG_SBIT	4			// Start bit(0~7)
#define LED7SEG_DIG_WIDTH	4			// Physical column(1~8)
//#define LED7SEG_DIG_REV				// Right->Left
#define LED7SEG_SEG_PORT	LATC		// Output register ".gfedcba"
#define LED7SEG_SEG_TRIS	TRISC		// Direction register
#define LED7SEG_SEG_POL		0			// Active low=0 high=1

// Internal table
extern const  unsigned char led7seg_Pat[];

//
//	API
//
extern void led7seg_Start(void);
extern void led7seg_PutPattern(unsigned char pat, unsigned char pos);
//     void led7seg_PutHex(unsigned char hex, unsigned char pos);
#define     led7seg_PutHex(hex, pos)	led7seg_PutPattern((led7seg_Pat[hex]), (pos))
extern void led7seg_DP(unsigned char f, unsigned char pos);
extern void led7seg_Dim(signed char dim);
extern void led7seg_DispInt(int iValue, unsigned char bPos, unsigned char bLen);
extern void led7seg_Refresh(void);		// Need interval call by user (~4[ms])
#define     led7seg_Update()			led7seg_Refresh()
extern void led7seg_Stop(void);
// call sequense: led7seg_Start() -> ... -> led7seg_Stop()
// pat:   Segment bit image(b7=dp b6=g b5=f ... b0=a)
// pos:   Digit position(1~LED7SEG_DIG_WIDTH, 0=all digit)
// hex:   Nibble data
// f:     Dot flag(on=1 off=0)
// dim:   Dimmer (bright=1 dark=0 little-dark=-1 more-dark=-2...)
// iValue:Display number
// bPos:  Start digit position(1~LED7SEG_DIG_WIDTH)
// bLen:  Display digit width

#endif